.. include:: ../README.rst

Tables of contents and indices
------------------------------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
